import { AttributeValue, ExpressionAttributes } from '@awslabs-community-fork/dynamodb-expressions';
export declare type Comparator<V> = {
    readonly '=': V;
} | {
    readonly '<': V;
} | {
    readonly '<=': V;
} | {
    readonly '>': V;
} | {
    readonly '>=': V;
} | {
    readonly '<>': V;
};
export declare type ConditionObject<A> = A extends Record<string, any> ? {
    readonly [k in keyof A]?: Comparator<A[k]> | ComparisonFunction<A[k]> | ConditionExpression<A[k]>;
} : never;
export declare type ConditionExpression<A> = BooleanCombinatorExpression<A> | ConditionObject<A> | readonly ConditionExpression<A>[];
declare type BooleanCombinatorExpression<A> = {
    readonly __type: 'boolean_combinator';
    readonly combinator: 'NOT';
    readonly expressions: readonly ConditionExpression<A>[];
} | {
    readonly __type: 'boolean_combinator';
    readonly combinator: 'AND';
    readonly expressions: readonly ConditionExpression<A>[];
} | {
    readonly __type: 'boolean_combinator';
    readonly combinator: 'OR';
    readonly expressions: readonly ConditionExpression<A>[];
};
export declare const NOT: <A>(...expressions: readonly ConditionExpression<A>[]) => ConditionExpression<A>;
export declare const AND: <A>(...expressions: readonly ConditionExpression<A>[]) => ConditionExpression<A>;
export declare const OR: <A>(...expressions: readonly ConditionExpression<A>[]) => ConditionExpression<A>;
declare type AttributeType = keyof AttributeValue;
export declare type ComparisonFunction<V> = {
    readonly __type: 'function';
    readonly function: 'attribute_exists';
} | {
    readonly __type: 'function';
    readonly function: 'attribute_not_exists';
} | {
    readonly __type: 'function';
    readonly function: 'attribute_type';
    readonly arg: AttributeType;
} | {
    readonly __type: 'function';
    readonly function: 'size';
    readonly comparator: Comparator<number>;
} | {
    readonly __type: 'function';
    readonly function: 'begins_with';
    readonly arg: string;
} | {
    readonly __type: 'function';
    readonly function: 'contains';
    readonly arg: string;
} | {
    readonly __type: 'function';
    readonly function: 'between';
    readonly lower: V;
    readonly upper: V;
} | {
    readonly __type: 'function';
    readonly function: 'in';
    readonly values: readonly V[];
};
export declare const attributeExists: <V>() => ComparisonFunction<V>;
export declare const attributeNotExists: <V>() => ComparisonFunction<V>;
export declare const size: <V>(c: Comparator<number>) => ComparisonFunction<V>;
export declare const attributeType: <V>(v: AttributeType) => ComparisonFunction<V>;
export declare const beginsWith: <V>(v: string) => {
    readonly __type: 'function';
    readonly function: 'begins_with';
    readonly arg: string;
};
export declare const contains: <V>(v: string) => ComparisonFunction<V>;
export declare const between: <V>(lower: V, upper: V) => {
    readonly __type: 'function';
    readonly function: 'between';
    readonly lower: V;
    readonly upper: V;
};
export declare const isIn: <V>(values: readonly V[]) => ComparisonFunction<V>;
export declare const serializeConditionExpression: <A>(expression: ConditionExpression<A>, attributes: ExpressionAttributes) => string;
export {};
