import { AttributeValue } from '@aws-sdk/client-dynamodb';
import { DynamoObject, DynamoPrimitive } from './types';
declare type DynamoMarshaller<T extends DynamoPrimitive> = {
    readonly to: (t: T) => AttributeValue;
    readonly from: (a: AttributeValue) => T;
    readonly optional: () => DynamoMarshaller<T | undefined>;
};
export declare type AttributeMap = {
    readonly [key: string]: AttributeValue;
};
export declare const marshaller: {
    marshallValue: (value: DynamoPrimitive) => AttributeValue;
    unmarshallValue: (value: AttributeValue) => any;
    marshallItem: (value: DynamoObject) => AttributeMap;
    unmarshallItem: (value: AttributeMap) => Record<string, any>;
};
export declare type Marshaller = typeof marshaller;
export declare type DynamoMarshallerFor<T extends DynamoObject> = {
    readonly [k in keyof T]: DynamoMarshaller<T[k]>;
};
export declare const Marshallers: {
    string: DynamoMarshaller<string>;
    number: DynamoMarshaller<number>;
    binary: DynamoMarshaller<ArrayBuffer>;
    bool: DynamoMarshaller<boolean>;
    stringSet: DynamoMarshaller<ReadonlySet<string>>;
    numberSet: DynamoMarshaller<ReadonlySet<number>>;
    map: <T extends DynamoObject>(schema: DynamoMarshallerFor<T>) => DynamoMarshaller<T>;
    arrayBuffer: DynamoMarshaller<ArrayBuffer>;
    arrayBufferView: DynamoMarshaller<ArrayBufferView>;
};
export declare const marshall: <T extends DynamoObject>(t: T) => AttributeValue;
export declare const unmarshall: <T extends DynamoObject>(schema: DynamoMarshallerFor<T>, item: AttributeMap) => T;
export {};
