import { DynamoDB, DynamoDBClientConfig } from '@aws-sdk/client-dynamodb';
import { marshallOptions, unmarshallOptions } from '@aws-sdk/util-dynamodb';
import { TableFactoryResult } from './table';
import { DynamoObject } from './types';
declare type Name = string;
export declare type Logger = {
    readonly debug: (msg: string, meta?: object) => unknown;
    readonly info: (msg: string, meta?: object) => unknown;
    readonly warn: (msg: string, meta?: object) => unknown;
    readonly error: (msg: string, meta?: object) => unknown;
};
export declare type IndexDefinition<T extends DynamoObject, PartitionKey extends string & keyof T = never, SortKey extends string & keyof T = never> = {
    readonly name: Name;
    readonly partitionKey: PartitionKey;
    readonly sortKey: SortKey;
};
export declare type IndexDefinitions = Record<string, IndexDefinition<any, any, any>>;
declare type WithKey<T extends DynamoObject> = {
    withKey<PK extends string & keyof T, SK extends string & keyof T = undefined>(pk: PK, sk?: SK): TableBuilder<T, PK, SK, {}>;
};
declare type WithIndexes<T extends DynamoObject, PartitionKey extends string & keyof T, SortKey extends string & keyof T, Ixs extends IndexDefinitions> = {
    withGlobalIndex<IxName extends Name, PK extends string & Exclude<keyof T, PartitionKey> = never, SK extends string & keyof T = never>(ixName: IxName, pk: PK, sk: SK): TableBuilder<T, PartitionKey, SortKey, Ixs & Record<IxName, IndexDefinition<T, PK, SK>>>;
    withLocalIndex<IxName extends Name, SK extends string & Exclude<keyof T, PartitionKey | SortKey> = never>(ixName: IxName, sk: SK): TableBuilder<T, PartitionKey, SortKey, Ixs & Record<IxName, IndexDefinition<T, PartitionKey, SK>>>;
};
export declare type DynamodbTableConfig = marshallOptions & unmarshallOptions & DynamoDBClientConfig & {
    readonly client?: DynamoDB;
    readonly logger?: Logger;
};
declare type Build<T extends DynamoObject, PartitionKey extends string & keyof T = never, SortKey extends string & keyof T = never, Ixs extends IndexDefinitions = {}> = {
    readonly build: (config?: DynamodbTableConfig) => TableFactoryResult<T, PartitionKey, SortKey, Ixs>;
};
export declare type TableBuilder<T extends DynamoObject, PartitionKey extends string & keyof T = undefined, SortKey extends string & keyof T = undefined, Ixs extends IndexDefinitions = {}> = {} & (PartitionKey extends undefined ? WithKey<T> : {}) & (SortKey extends undefined ? {} : WithIndexes<T, PartitionKey, SortKey, Ixs>) & (PartitionKey extends undefined ? {} : Build<T, PartitionKey, SortKey, Ixs>);
export declare type TableDefinition<T extends DynamoObject, PartitionKey extends (string & keyof T) | undefined = undefined, SortKey extends (string & keyof T) | undefined = undefined, Ixs extends IndexDefinitions = {}> = {
    readonly name: string;
    readonly partitionKey: PartitionKey;
    readonly sortKey?: SortKey;
    readonly indexes: Ixs;
};
export declare const tableBuilder: <T extends DynamoObject>(name: string) => WithKey<T>;
export {};
