declare type ValueOf<T> = T[keyof T];
export declare type DynamoKeyTypes = string | number | ArrayBuffer | ArrayBufferView;
export declare type DynamoObjectOf<T> = T extends Record<string, unknown> ? {
    readonly [K in keyof T]: DynamoObjectOf<T[K]>;
} : T extends DynamoPrimitive ? T : never;
export declare type DynamoObject = {
    [key: string]: DynamoPrimitive;
};
declare type DynamoSet<T> = ReadonlySet<T> | Set<T>;
export declare type RequireAtLeastOne<T, Keys extends keyof T = keyof T> = Pick<T, Exclude<keyof T, Keys>> & {
    [K in Keys]-?: Required<Pick<T, K>> & Partial<Pick<T, Exclude<Keys, K>>>;
}[Keys];
export declare type DynamoPrimitive = DynamoKeyTypes | Iterable<ArrayBufferView> | Iterable<ArrayBuffer> | boolean | DynamoSet<string> | DynamoSet<number> | DynamoPrimitive[] | DynamoObject | undefined;
export declare type DynamoValueKeys<T extends DynamoObject> = ValueOf<{
    [key in keyof T]: T[key] extends DynamoKeyTypes ? key : never;
}>;
export declare type RecursivePartial<T> = {
    readonly [P in keyof T]?: T[P] extends readonly (infer U)[] ? readonly RecursivePartial<U>[] : T[P] extends Record<string, unknown> ? RecursivePartial<T[P]> : T[P];
};
declare type Prev = [never, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
export declare type NestedKeyOf<T, D extends number = 3> = [D] extends [never] ? never : T extends object ? {
    [K in keyof T]-?: Join<K, NestedKeyOf<T[K], Prev[D]>>;
}[keyof T] : '';
declare type UnionToIntersection<U> = (U extends any ? (k: U) => void : never) extends (k: infer I) => void ? I : never;
declare type Join<K, P> = K extends string | number ? P extends string | number ? `${K}${'' extends P ? '' : '.'}${P}` : never : never;
declare type _NestedPick<A, K extends string, Agg = {}> = K extends `${infer Key}.${infer Rest}` ? Key extends keyof A ? A[Key] extends object ? {
    [s in Key]: _NestedPick<A[Key], Rest, Agg>;
} : never : never : K extends keyof A & string ? Agg & {
    [s in K]: A[K];
} : never;
export declare type NestedPick<A, K extends string> = UnionToIntersection<_NestedPick<A, K>>;
export {};
